命令行：
kk
参数:
    -port=8000  端口号，默认端口为8000
    -path=.     显示目录，默认为当前目录
    -dev=False  开发者模式，默认为False
    -all=True  是否显示隐藏文件，默认为True

在显示的文件列表标题上，点击“切换显示”将切换是否直接显示图片/视频/音乐。
默认支持的URL参数:
    w=256:  显示图片宽
    h=256:  显示图片高
    f=json: 以json格式显示数据 

支持表格和统计图表显示，需要先按照mongodb用于数据存储
